@@ -5,9 +5,10 @@ __all__ = ['request', 'HttpClient']
 import asyncio
 import collections
 import http.cookies
-import json
-import io
 import inspect
+import io
+import json
+import mimetypes
 import random
 import time
 import urllib.parse
@@ -89,6 +90,7 @@ def request(method, url, *,
 
     """
     redirects = 0
+    method = method.upper()
     if loop is None:
         loop = asyncio.get_event_loop()
     if request_class is None:
@@ -119,12 +121,19 @@ def request(method, url, *,
             raise aiohttp.OsConnectionError(exc)
 
         # redirects
-        if resp.status in (301, 302) and allow_redirects:
+        if resp.status in (301, 302, 303, 307) and allow_redirects:
             redirects += 1
             if max_redirects and redirects >= max_redirects:
                 resp.close(force=True)
                 break
 
+            # For 301 and 302, mimic IE behaviour, now changed in RFC.
+            # Details: https://github.com/kennethreitz/requests/pull/269
+            if resp.status != 307:
+                method = 'GET'
+                data = None
+            cookies = resp.cookies
+
             r_url = resp.headers.get('LOCATION') or resp.headers.get('URI')
 
             scheme = urllib.parse.urlsplit(r_url)[0]
@@ -373,6 +382,20 @@ class ClientRequest:
             if 'CONTENT-LENGTH' not in self.headers and self.chunked is None:
                 self.chunked = True
 
+        elif isinstance(data, io.IOBase):
+            assert not isinstance(data, io.StringIO), \
+                'attempt to send text data instead of binary'
+            self.body = data
+            self.chunked = True
+            if hasattr(data, 'mode'):
+                if data.mode == 'r':
+                    raise ValueError('file {!r} should be open in binary mode'
+                                     ''.format(data))
+            if 'CONTENT-TYPE' not in self.headers and hasattr(data, 'name'):
+                mime = mimetypes.guess_type(data.name)[0]
+                mime = 'application/octet-stream' if mime is None else mime
+                self.headers['CONTENT-TYPE'] = mime
+
         else:
             if not isinstance(data, helpers.FormData):
                 data = helpers.FormData(data)
@@ -474,6 +497,12 @@ class ClientRequest:
                     except streams.EofStream:
                         break
 
+            elif isinstance(self.body, io.IOBase):
+                chunk = self.body.read(self.chunked)
+                while chunk:
+                    request.write(chunk)
+                    chunk = self.body.read(self.chunked)
+
             else:
                 if isinstance(self.body, (bytes, bytearray)):
                     self.body = (self.body,)
