@@ -9,7 +9,7 @@ import traceback
 import socket
 
 import aiohttp
-from aiohttp import errors, streams, utils
+from aiohttp import errors, streams, helpers
 from aiohttp.log import server_log, access_log
 
 
@@ -33,18 +33,35 @@ class ServerHttpProtocol(aiohttp.StreamProtocol):
     """Simple http protocol implementation.
 
     ServerHttpProtocol handles incoming http request. It reads request line,
-    request headers and request payload and calls handler_request() method.
+    request headers and request payload and calls handle_request() method.
     By default it always returns with 404 response.
 
     ServerHttpProtocol handles errors in incoming request, like bad
     status line, bad headers or incomplete payload. If any error occurs,
     connection gets closed.
 
-    log: custom logging object
-    debug: enable debug mode
-    keep_alive: number of seconds before closing keep alive connection
-    timeout: slow request timeout
-    loop: event loop object
+    :param keep_alive: number of seconds before closing keep-alive connection
+    :type keep_alive: int or None
+
+    :param int timeout: slow request timeout
+
+    :param bool tcp_keepalive: TCP socket keep-alive flag
+
+    :param allowed_methods: (optional) List of allowed request methods.
+                            Set to empty list to allow all methods.
+    :type allowed_methods: tuple
+
+    :param bool debug: enable debug mode
+
+    :param log: custom logging object
+    :type log: aiohttp.log.server_log
+
+    :param access_log: custom logging object
+    :type access_log: aiohttp.log.server_log
+
+    :param str access_log_format: access log format string
+
+    :param loop: Optional event loop
     """
     _request_count = 0
     _request_handler = None
@@ -110,14 +127,18 @@ class ServerHttpProtocol(aiohttp.StreamProtocol):
             self._timeout_handle = None
 
     def keep_alive(self, val):
+        """Set keep-alive connection mode.
+
+        :param bool val: new state.
+        """
         self._keep_alive = val
 
     def log_access(self, message, environ, response, time):
         if self.access_log and self.access_log_format:
             try:
                 environ = environ if environ is not None else {}
-                atoms = utils.SafeAtoms(
-                    utils.atoms(message, environ, response, time),
+                atoms = helpers.SafeAtoms(
+                    helpers.atoms(message, environ, response, time),
                     getattr(message, 'headers', None),
                     getattr(response, 'headers', None))
                 self.access_log.info(self.access_log_format % atoms)
@@ -144,6 +165,7 @@ class ServerHttpProtocol(aiohttp.StreamProtocol):
     @asyncio.coroutine
     def start(self):
         """Start processing of incoming requests.
+
         It reads request line, request headers and request payload, then
         calls handle_request() method. Subclass has to override
         handle_request(). start() handles various exceptions in request
@@ -201,6 +223,10 @@ class ServerHttpProtocol(aiohttp.StreamProtocol):
             except Exception as exc:
                 self.handle_error(500, message, None, exc)
             finally:
+                if self.transport is None:
+                    self.log_debug('Ignored premature client disconnection.')
+                    break
+
                 if payload and not payload.is_eof():
                     self.log_debug('Uncompleted request.')
                     self._request_handler = None
@@ -276,8 +302,10 @@ class ServerHttpProtocol(aiohttp.StreamProtocol):
         Subclass should override this method. By default it always
         returns 404 response.
 
-        info: aiohttp.RequestLine instance
-        message: aiohttp.RawHttpMessage instance
+        :param message: Request headers
+        :type message: aiohttp.protocol.HttpRequestParser
+        :param payload: Request payload
+        :type payload: aiohttp.streams.FlowControlStreamReader
         """
         now = time.time()
         response = aiohttp.Response(
