@@ -202,6 +202,19 @@ class HttpClientFunctionalTests(unittest.TestCase):
             content = self.loop.run_until_complete(r.content.read())
             content = content.decode()
 
+            self.assertEqual(r.status, 200)
+            self.assertIn('"method": "GET"', content)
+            self.assertEqual(2, httpd['redirects'])
+            r.close()
+
+    def test_HTTP_307_REDIRECT_POST(self):
+        with test_utils.run_server(self.loop, router=Functional) as httpd:
+            r = self.loop.run_until_complete(
+                client.request('post', httpd.url('redirect_307', 2),
+                               data={'some': 'data'}, loop=self.loop))
+            content = self.loop.run_until_complete(r.content.read())
+            content = content.decode()
+
             self.assertEqual(r.status, 200)
             self.assertIn('"method": "POST"', content)
             self.assertEqual(2, httpd['redirects'])
@@ -470,21 +483,25 @@ class HttpClientFunctionalTests(unittest.TestCase):
             url = httpd.url('method', 'post')
 
             with open(__file__) as f:
+                with self.assertRaises(ValueError):
+                    self.loop.run_until_complete(
+                        client.request('post', url, data=f, loop=self.loop))
+
+    def test_POST_FILES_SINGLE_BINARY(self):
+        with test_utils.run_server(self.loop, router=Functional) as httpd:
+            url = httpd.url('method', 'post')
+
+            with open(__file__, 'rb') as f:
                 r = self.loop.run_until_complete(
                     client.request('post', url, data=f, loop=self.loop))
 
                 content = self.loop.run_until_complete(r.json())
 
                 f.seek(0)
-                filename = os.path.split(f.name)[-1]
-
-                self.assertEqual(1, len(content['multipart-data']))
-                self.assertEqual(
-                    filename, content['multipart-data'][0]['name'])
-                self.assertEqual(
-                    filename, content['multipart-data'][0]['filename'])
-                self.assertEqual(
-                    f.read(), content['multipart-data'][0]['data'])
+                self.assertEqual(0, len(content['multipart-data']))
+                self.assertEqual(content['content'], f.read().decode())
+                self.assertEqual(content['headers']['Content-Type'],
+                                 'text/x-python')
                 self.assertEqual(r.status, 200)
                 r.close()
 
@@ -929,6 +946,20 @@ class Functional(test_utils.Router):
                 self._start_response(302),
                 headers={'Location': self._path})
 
+    @test_utils.Router.define('/redirect_307/([0-9]+)$')
+    def redirect_307(self, match):
+        no = int(match.group(1).upper())
+        rno = self._props['redirects'] = self._props.get('redirects', 0) + 1
+
+        if rno >= no:
+            self._response(
+                self._start_response(307),
+                headers={'Location': '/method/%s' % self._method.lower()})
+        else:
+            self._response(
+                self._start_response(307),
+                headers={'Location': self._path})
+
     @test_utils.Router.define('/encoding/(gzip|deflate)$')
     def encoding(self, match):
         mode = match.group(1)
